@@ -8,7 +8,7 @@ import io
 from collections import defaultdict
 from copy import deepcopy
 from dataclasses import dataclass
-from datetime import datetime
+from datetime import datetime, timezone
 from enum import Enum
 from importlib.metadata import version
 from typing import Any, Callable, Dict, List, Optional, Tuple, Type, TypeVar
@@ -71,10 +71,11 @@ class DAPIServerRequestType(Enum):
 
     CLIENT_CONFIG = "/v1/config/client/opendapi"
     CLIENT_FEATURE_FLAGS = "/v1/config/client/opendapi/feature_flags"
-    GITHUB_BUILDKITE_CICD_START = "/v1/cicd/start/github_buildkite"
-    GITHUB_GITHUB_CICD_START = "/v1/cicd/start/github_github"
-    CICD_COMPLETE_BLUEPRINT = "/v1/cicd/complete/{integration}"
-    CICD_GET_PRESIGNED_LINK_BLUEPRINT = "/v1/cicd/files/persist/{integration}/presigned"
+    CICD_GET_CICD_LOCATION_ID = "/v2/cicd/cicd_location_id"
+    GITHUB_BUILDKITE_CICD_START = "/v2/cicd/start/github_buildkite"
+    GITHUB_GITHUB_CICD_START = "/v2/cicd/start/github_github"
+    CICD_GET_PRESIGNED_LINK_BLUEPRINT = "/v2/cicd/files/persist/presigned"
+    CICD_GET_MISSING_DAPIS = "/v2/cicd/dapi/missing"
 
 
 @dataclass
@@ -322,6 +323,7 @@ class DAPIRequests:
             backoff_factor=RETRY_BACKOFF_FACTOR,
             status_forcelist=[500, 502, 503, 504],
             allowed_methods=["POST", "GET"],
+            print_retries=True,
         )
 
     def get_client_config_from_server(self) -> dict:
@@ -420,75 +422,47 @@ class DAPIRequests:
             self.error_msg_handler(msg)
         raise self.error_exception_cls(msg)
 
-    def _github_repo_cicd_init(
-        self,
-        request_path: str,
-        runner_params: Dict[str, Any],
-    ) -> Tuple[str, dict]:
-        """
-        Returns a common payload for all github repo operations
-        """
+    ##### 1) Get CICD Location ID #####
 
+    def cicd_get_cicd_location_id(self) -> Tuple[str, dict]:
+        """Get the S3 prefix for the CI/CD."""
+
+        if not self.trigger_event.after_change_sha_timestamp:  # pragma: no cover
+            raise ValueError("head_commit_sha_timestamp is required")
+
+        request_path = DAPIServerRequestType.CICD_GET_CICD_LOCATION_ID.value
         response, _ = self.raw_send_request_to_dapi_server(
             request_path=request_path,
             query_params={
                 "repo_name": self.trigger_event.repo_full_name,
-            },
-            body_json={
-                "event": self.trigger_event.event_type,
-                "branch": self.trigger_event.branch,
-                "base_commit_sha": self.trigger_event.before_change_sha,
                 "head_commit_sha": self.trigger_event.after_change_sha,
                 "head_commit_sha_timestamp": self.trigger_event.after_change_sha_timestamp,
-                "pr_link": self.trigger_event.pull_request_link,
-                "version": f"opendapi-{version('opendapi')}",
-                **runner_params,
             },
-            method=HTTPMethod.POST,
+            method=HTTPMethod.GET,
         )
-
         if response.status_code >= 400:
-            self._handle_api_error(
-                request_path,
-                response.status_code,
-            )
-
+            self._handle_api_error(request_path, response.status_code)
         response_json = response.json()
-        return response_json["woven_cicd_id"], response_json["s3_upload_data"]
+        return response_json["cicd_location_id"], response_json["s3_upload_data"]
 
-    def cicd_init_github_buildkite(
-        self,
-        job_id: str,
-        job_started_at: datetime,
-        build_id: str,
-        retry_count: Optional[int] = None,
-    ) -> Tuple[str, dict]:
-        """Notify the DAPI Server that the GitHub CI/CD has started."""
-        return self._github_repo_cicd_init(
-            DAPIServerRequestType.GITHUB_BUILDKITE_CICD_START.value,
-            {
-                "job_id": job_id,
-                "job_started_at": job_started_at.isoformat(),
-                "build_id": build_id,
-                "retry_count": retry_count,
-            },
-        )
+    ##### 2) Persisting Files to S3 #####
 
-    def cicd_init_github_github(
+    def cicd_get_s3_upload_data(
         self,
-        run_id: str,
-        run_attempt: int,
-        run_number: int,
-    ) -> Tuple[str, dict]:
-        """Notify the DAPI Server that the GitHub CI/CD has started."""
-        return self._github_repo_cicd_init(
-            DAPIServerRequestType.GITHUB_GITHUB_CICD_START.value,
-            {
-                "run_id": run_id,
-                "run_attempt": run_attempt,
-                "run_number": run_number,
+        cicd_location_id: str,
+    ) -> dict:
+        """Get the S3 upload data for the CI/CD."""
+        request_path = DAPIServerRequestType.CICD_GET_PRESIGNED_LINK_BLUEPRINT.value
+        response, _ = self.raw_send_request_to_dapi_server(
+            request_path=request_path,
+            query_params={
+                "cicd_location_id": cicd_location_id,
             },
+            method=HTTPMethod.GET,
         )
+        if response.status_code >= 400:
+            self._handle_api_error(request_path, response.status_code)
+        return response.json()["s3_upload_data"]
 
     async def __upload_to_s3(
         self,
@@ -654,48 +628,116 @@ class DAPIRequests:
 
         return asyncio.run(_cicd_persist_files())
 
-    def cicd_start(
+    ##### 3) CICD Start #####
+
+    def _github_repo_cicd_start(
         self,
-        integration: CICDIntegration,
+        cicd_location_id: str,
         metadata_file: Dict[str, Any],
-        woven_cicd_id: str,
-    ) -> None:
-        """Notify the DAPI Server that the CI/CD has completed."""
-        request_path = DAPIServerRequestType.CICD_COMPLETE_BLUEPRINT.value.format(
-            integration=integration.value
-        )
+        request_path: str,
+        runner_params: Dict[str, Any],
+    ) -> str:
+        """
+        Returns a common payload for all github repo operations
+        """
+
         response, _ = self.raw_send_request_to_dapi_server(
             request_path=request_path,
             query_params={
-                "woven_cicd_id": woven_cicd_id,
+                # global query
+                "cicd_location_id": cicd_location_id,
             },
             body_json={
+                # global body
                 "metadata": metadata_file,
+                "version": f"opendapi-{version('opendapi')}",
+                # runner body
+                **runner_params,
+                # github repo body
+                "event": self.trigger_event.event_type,
+                "branch": self.trigger_event.branch,
+                "base_commit_sha": self.trigger_event.before_change_sha,
+                "head_commit_sha": self.trigger_event.after_change_sha,
+                "pr_link": self.trigger_event.pull_request_link,
+                # default global body
                 "logs": logger.get_logs(),
             },
             method=HTTPMethod.POST,
         )
+
+        if response.status_code >= 400:
+            self._handle_api_error(
+                request_path,
+                response.status_code,
+            )
+
+        return response.json()["woven_cicd_id"]
+
+    def cicd_start_github_buildkite(
+        self,
+        cicd_location_id: str,
+        build_id: str,
+        build_number: int,
+        metadata_file: Dict[str, Any],
+    ) -> str:
+        """Notify the DAPI Server that the GitHub CI/CD has started."""
+        return self._github_repo_cicd_start(
+            cicd_location_id,
+            metadata_file,
+            DAPIServerRequestType.GITHUB_BUILDKITE_CICD_START.value,
+            {
+                "build_id": build_id,
+                "build_number": build_number,
+                # NOTE: this is not exact - if we could get it we should use that.
+                #       but this is here so that successes come after failures and so
+                #       we can sort successful runs
+                "build_started_at": datetime.now(timezone.utc).isoformat(),
+                "pipeline_name": self.trigger_event.workflow_name,
+            },
+        )
+
+    def cicd_start_github_github(
+        self,
+        cicd_location_id: str,
+        run_id: str,
+        run_attempt: int,
+        run_number: int,
+        metadata_file: Dict[str, Any],
+    ) -> str:
+        """Notify the DAPI Server that the GitHub CI/CD has started."""
+        return self._github_repo_cicd_start(
+            cicd_location_id,
+            metadata_file,
+            DAPIServerRequestType.GITHUB_GITHUB_CICD_START.value,
+            {
+                "run_id": run_id,
+                "run_attempt": run_attempt,
+                "run_number": run_number,
+                # NOTE: this is not exact - if we could get it we should use that.
+                #       but this is here so that successes come after failures and so
+                #       we can sort successful runs
+                "run_started_at": datetime.now(timezone.utc).isoformat(),
+                "workflow_name": self.trigger_event.workflow_name,
+            },
+        )
+
+    ##### Missing DAPI Helper #####
+
+    def cicd_get_missing_dapis(self) -> dict[str, dict]:
+        """
+        Get the missing DAPI files for the CICD run.
+
+        NOTE: this DOES NOT prefix with the root dir
+        """
+        request_path = DAPIServerRequestType.CICD_GET_MISSING_DAPIS.value
+        response, _ = self.raw_send_request_to_dapi_server(
+            request_path=request_path,
+            method=HTTPMethod.GET,
+            query_params={
+                "repo_name": self.trigger_event.repo_full_name,
+            },
+        )
         if response.status_code >= 400:
             self._handle_api_error(request_path, response.status_code)
 
-    def cicd_get_s3_upload_data(
-        self,
-        woven_cicd_id: str,
-        integration: CICDIntegration,
-    ) -> dict:
-        """Get the S3 upload data for the CI/CD."""
-        request_path = (
-            DAPIServerRequestType.CICD_GET_PRESIGNED_LINK_BLUEPRINT.value.format(
-                integration=integration.value
-            )
-        )
-        response, _ = self.raw_send_request_to_dapi_server(
-            request_path=request_path,
-            query_params={
-                "woven_cicd_id": woven_cicd_id,
-            },
-            method=HTTPMethod.GET,
-        )
-        if response.status_code >= 400:
-            self._handle_api_error(request_path, response.status_code)
-        return response.json()["s3_upload_data"]
+        return response.json()["missing_dapi_dicts_by_filepath"]
