@@ -7,12 +7,12 @@ import click
 
 from opendapi import templates
 from opendapi.cli.common import check_command_invocation_in_root, print_cli_output
-from opendapi.config import SUPPORTED_DAPI_INTEGRATIONS
 from opendapi.defs import (
     CONFIG_FILEPATH_FROM_ROOT_DIR,
     DEFAULT_DAPI_SERVER_HOSTNAME,
     DEFAULT_DAPIS_DIR,
     GITHUB_ACTIONS_FILEPATH_FROM_ROOT_DIR,
+    ORMIntegration,
 )
 from opendapi.utils import get_repo_name_from_root_dir, make_snake_case
 
@@ -51,8 +51,8 @@ def _create_from_template(
 
 def _validate_integrations(ctx, param, value):  # pylint: disable=unused-argument
     """Callback to validate the integrations."""
-    if value and not set(value).issubset(set(SUPPORTED_DAPI_INTEGRATIONS)):
-        integrations = "\n * ".join([""] + sorted(SUPPORTED_DAPI_INTEGRATIONS))
+    if value and not set(value).issubset(set(el.value for el in ORMIntegration)):
+        integrations = "\n * ".join([""] + sorted(el.value for el in ORMIntegration))
         raise click.BadParameter(f"Integration must be one of: {integrations}")
     return value
 
@@ -67,7 +67,7 @@ def _prompt_for_integrations() -> List[str]:
     while True:
         value = click.prompt(
             "Integration name",
-            type=click.Choice(list(sorted(SUPPORTED_DAPI_INTEGRATIONS)) + [""]),
+            type=click.Choice(list(sorted(el.value for el in ORMIntegration)) + [""]),
             default="",
             show_default=False,
         )
@@ -107,7 +107,7 @@ def _prompt_for_integrations() -> List[str]:
     default=set(),
     callback=_validate_integrations,
     help="The integrations to be used. "
-    f"One of: {SUPPORTED_DAPI_INTEGRATIONS}. "
+    f"One of: {', '.join(el.value for el in ORMIntegration)}."
     "Can be used multiple times.",
 )
 @click.option(
