@@ -9,8 +9,6 @@ This command is invoked in a buildkite CI runner for a github repo and a single
 
 # pylint: disable=duplicate-code
 
-import datetime
-
 import click
 
 from opendapi.adapters.dapi_server import CICDIntegration
@@ -23,15 +21,16 @@ from opendapi.cli.context_agnostic import (
     server_sync_minimal_schemas,
 )
 from opendapi.cli.options import (
+    OPENDAPI_CONFIG_PARAM_NAME_WITH_OPTION,
     SKIP_DBT_INTEGRATION_BASE_GENERATION_OPTION,
     SKIP_DBT_INTEGRATION_HEAD_GENERATION_OPTION,
     SKIP_RUNTIME_INTEGRATION_BASE_GENERATION_OPTION,
     SKIP_RUNTIME_INTEGRATION_HEAD_GENERATION_OPTION,
     dapi_server_options,
-    dbt_options,
     dev_options,
     generation_options,
     opendapi_run_options,
+    schema_integration_options,
 )
 from opendapi.cli.repos.github.options import repo_options
 from opendapi.cli.repos.github.runners.buildkite.options import (
@@ -44,7 +43,7 @@ from opendapi.defs import CommitType
 @click.command()
 # common options
 @dapi_server_options
-@dbt_options
+@schema_integration_options
 @dev_options
 @generation_options
 @opendapi_run_options
@@ -79,7 +78,9 @@ def cli(**kwargs):  # pylint: disable=too-many-locals
     )
 
     change_trigger_event = construct_change_trigger_event(kwargs)
-    opendapi_config = get_opendapi_config_from_root(
+    opendapi_config = kwargs.get(
+        OPENDAPI_CONFIG_PARAM_NAME_WITH_OPTION.name
+    ) or get_opendapi_config_from_root(
         local_spec_path=kwargs.get("local_spec_path"),
         validate_config=True,
     )
@@ -94,6 +95,7 @@ def cli(**kwargs):  # pylint: disable=too-many-locals
         minimal_schemas=server_sync_minimal_schemas(),
         runtime=runtime,
         commit_already_checked_out=False,
+        kwargs=kwargs,
     )
     head_collected_files = collect_collected_files(
         opendapi_config,
@@ -104,24 +106,19 @@ def cli(**kwargs):  # pylint: disable=too-many-locals
         minimal_schemas=server_sync_minimal_schemas(),
         runtime=runtime,
         commit_already_checked_out=True,
+        kwargs=kwargs,
     )
 
-    job_id = kwargs["buildkite_job_id"]
     # NOTE: we may want to make this an envvar set by the script,
     #       but this works for now. The ideal case is we pull this from BK API,
     #       which we will need anyway for DBT, but this is fine for now.
-    job_started_at = datetime.datetime.now(datetime.timezone.utc)
     build_id = kwargs["buildkite_build_id"]
-    retry_count = kwargs["buildkite_retry_count"]
-    woven_cicd_id, s3_upload_data = cicd_init(
-        lambda dr: dr.cicd_init_github_buildkite(
-            job_id=job_id,
-            job_started_at=job_started_at,
-            build_id=build_id,
-            retry_count=retry_count,
-        ),
+    build_number = kwargs["buildkite_build_number"]
+    cicd_location_id, s3_upload_data = cicd_init(
+        opendapi_config,
         change_trigger_event,
         kwargs,
+        should_write_cicd_initialized_file=False,
     )
     cicd_persist_files(
         base_collected_files,
@@ -133,14 +130,19 @@ def cli(**kwargs):  # pylint: disable=too-many-locals
         kwargs,
     )
     cicd_start(
-        woven_cicd_id,
+        lambda dr, mf: dr.cicd_start_github_buildkite(
+            cicd_location_id=cicd_location_id,
+            build_id=build_id,
+            build_number=build_number,
+            metadata_file=mf,
+        ),
+        cicd_location_id,
         opendapi_config,
         change_trigger_event,
         CICDIntegration.GITHUB_BUILDKITE,
         {
-            "job_id": job_id,
             "build_id": build_id,
-            "retry_count": retry_count,
+            "build_number": build_number,
         },
         kwargs,
     )
