@@ -21,15 +21,16 @@ from opendapi.cli.context_agnostic import (
     server_sync_minimal_schemas,
 )
 from opendapi.cli.options import (
+    OPENDAPI_CONFIG_PARAM_NAME_WITH_OPTION,
     SKIP_DBT_INTEGRATION_BASE_GENERATION_OPTION,
     SKIP_DBT_INTEGRATION_HEAD_GENERATION_OPTION,
     SKIP_RUNTIME_INTEGRATION_BASE_GENERATION_OPTION,
     SKIP_RUNTIME_INTEGRATION_HEAD_GENERATION_OPTION,
     dapi_server_options,
-    dbt_options,
     dev_options,
     generation_options,
     opendapi_run_options,
+    schema_integration_options,
 )
 from opendapi.cli.repos.github.options import repo_options
 from opendapi.cli.repos.github.runners.github.options import (
@@ -42,7 +43,7 @@ from opendapi.defs import CommitType
 @click.command()
 # common options
 @dapi_server_options
-@dbt_options
+@schema_integration_options
 @dev_options
 @generation_options
 @opendapi_run_options
@@ -74,7 +75,9 @@ def cli(**kwargs):
     ]
 
     change_trigger_event = construct_change_trigger_event(kwargs)
-    opendapi_config = get_opendapi_config_from_root(
+    opendapi_config = kwargs.get(
+        OPENDAPI_CONFIG_PARAM_NAME_WITH_OPTION.name
+    ) or get_opendapi_config_from_root(
         local_spec_path=kwargs.get("local_spec_path"),
         validate_config=True,
     )
@@ -89,6 +92,7 @@ def cli(**kwargs):
         minimal_schemas=server_sync_minimal_schemas(),
         runtime=runtime,
         commit_already_checked_out=False,
+        kwargs=kwargs,
     )
     head_collected_files = collect_collected_files(
         opendapi_config,
@@ -99,19 +103,17 @@ def cli(**kwargs):
         minimal_schemas=server_sync_minimal_schemas(),
         runtime=runtime,
         commit_already_checked_out=True,
+        kwargs=kwargs,
     )
 
     run_id = kwargs["github_run_id"]
     run_attempt = kwargs["github_run_attempt"]
     run_number = kwargs["github_run_number"]
-    woven_cicd_id, s3_upload_data = cicd_init(
-        lambda dr: dr.cicd_init_github_github(
-            run_id=run_id,
-            run_attempt=run_attempt,
-            run_number=run_number,
-        ),
+    cicd_location_id, s3_upload_data = cicd_init(
+        opendapi_config,
         change_trigger_event,
         kwargs,
+        should_write_cicd_initialized_file=False,
     )
     cicd_persist_files(
         base_collected_files,
@@ -122,8 +124,16 @@ def cli(**kwargs):
         runtime,
         kwargs,
     )
+
     cicd_start(
-        woven_cicd_id,
+        lambda dr, mf: dr.cicd_start_github_github(
+            cicd_location_id=cicd_location_id,
+            run_id=run_id,
+            run_attempt=run_attempt,
+            run_number=run_number,
+            metadata_file=mf,
+        ),
+        cicd_location_id,
         opendapi_config,
         change_trigger_event,
         CICDIntegration.GITHUB_GITHUB,
