@@ -4,6 +4,7 @@ in addition for the change_trigger_event construction
 """
 
 from opendapi.adapters.git import ChangeTriggerEvent
+from opendapi.cli.options import BASE_COMMIT_SHA_PARAM_NAME_WITH_OPTION
 
 
 def construct_change_trigger_event(kwargs: dict) -> ChangeTriggerEvent:
@@ -13,6 +14,9 @@ def construct_change_trigger_event(kwargs: dict) -> ChangeTriggerEvent:
     """
     return ChangeTriggerEvent(
         where="local",
-        before_change_sha=kwargs["mainline_branch_name"],
+        before_change_sha=(
+            kwargs.get(BASE_COMMIT_SHA_PARAM_NAME_WITH_OPTION.name)
+            or kwargs["mainline_branch_name"]
+        ),
         after_change_sha="HEAD",
     )
