@@ -2,6 +2,8 @@
 
 from __future__ import annotations
 
+import base64
+import json
 import os
 import re
 from typing import Dict, List, Optional
@@ -9,14 +11,15 @@ from typing import Dict, List, Optional
 from jsonschema import validate as jsonschema_validate
 
 from opendapi.defs import CONFIG_FILEPATH_FROM_ROOT_DIR, ORMIntegration
-from opendapi.models import PlaybookConfig
+from opendapi.models import NameTransform, PlaybookConfig
 from opendapi.utils import fetch_schema, make_snake_case, read_yaml_or_json
 
 
 def _extract_source_sink(playbook: PlaybookConfig, table_name: str) -> Dict:
     """Extract the source or sink from the playbook"""
     namespace = playbook.namespace
-    identifier = f"{playbook.identifier_prefix or ''}{table_name}"
+    name_transform = playbook.name_transform
+    identifier = f"{playbook.identifier_prefix or ''}{NameTransform.apply(name_transform, table_name)}"
     data = {"identifier": identifier}
     if namespace:
         data["namespace"] = namespace
@@ -133,31 +136,44 @@ class OpenDAPIConfig:
         self,
         root_dir: str,
         local_spec_path: Optional[str] = None,
+        serialized_config: Optional[str] = None,
     ):
         self.root_dir = root_dir
-        self.config = self._read_config()
+        self.config = (
+            self._load_config(serialized_config)
+            if serialized_config
+            else self._read_config()
+        )
         self.local_spec_path = local_spec_path
 
+    def _ensure_schema_backfill_runtimes(self, config: dict) -> dict:
+        """Ensure the schema backfill runtimes are present"""
+        if "schema" not in config:
+            raise ValueError("Invalid OpenDAPI config file: missing schema")
+
+        # NOTE: this is a HACK to allow configs that do not specify runtimes
+        #       to still work with the new runtime structure
+        if "runtimes" not in config["dapis"]:
+            config["dapis"]["runtimes"] = {
+                OpenDAPIConfig.DEFAULT_RUNTIME: {
+                    "integrations": config["dapis"].pop("integrations")
+                }
+            }
+
+        return config
+
+    def _load_config(self, serialized_config: str) -> dict:
+        """Load the config from the file"""
+        return self._ensure_schema_backfill_runtimes(
+            json.loads(base64.b64decode(serialized_config))
+        )
+
     def _read_config(self) -> dict:
         """Read the contents of the opendapi.config.yaml file"""
         config_file = self.config_full_path(self.root_dir)
         if os.path.exists(config_file):
             content = read_yaml_or_json(config_file)
-            if "schema" not in content:
-                raise ValueError(
-                    f"Invalid OpenDAPI config file: {config_file} missing schema"
-                )
-
-            # NOTE: this is a HACK to allow configs that do not specify runtimes
-            #       to still work with the new runtime structure
-            if "runtimes" not in content["dapis"]:
-                content["dapis"]["runtimes"] = {
-                    OpenDAPIConfig.DEFAULT_RUNTIME: {
-                        "integrations": content["dapis"].pop("integrations")
-                    }
-                }
-
-            return content
+            return self._ensure_schema_backfill_runtimes(content)
 
         raise FileNotFoundError(f"OpenDAPI config file not found: {config_file}")
 
@@ -261,3 +277,7 @@ class OpenDAPIConfig:
                 f"The available runtimes are: {self.runtime_names}"
             )
         return runtime
+
+    def get_serialized(self) -> dict:
+        """Return the config for the file"""
+        return base64.b64encode(json.dumps(self.config).encode()).decode()
