@@ -10,6 +10,7 @@ import io
 import json
 import os
 import re
+import sys
 from copy import deepcopy
 from functools import cmp_to_key, lru_cache
 from importlib.metadata import version
@@ -36,6 +37,7 @@ from urllib.parse import urlparse
 import jsonref
 import requests
 import requests_cache
+import urllib3
 from jsonschema import validators
 from jsonschema.validators import validator_for
 from requests.adapters import HTTPAdapter
@@ -264,7 +266,7 @@ def fetch_schema(schema_url: str) -> dict:
         raise ValueError(
             f"Unsupported schema found at {schema_url} - must use {OPENDAPI_DOMAIN}"
         )
-    return get_schema_session().get(schema_url, timeout=3).json()
+    return get_schema_session().get(schema_url, timeout=(10, 10)).json()
 
 
 def sort_dict_by_keys(dct: dict) -> dict:
@@ -515,12 +517,38 @@ def build_location_without_repo_from_fullpath(root_dir: str, fullpath: str):
     return re.sub(root_dir, "", fullpath).lstrip("/")
 
 
+class StdOutRetry(Retry):
+    """Retry that prints the request and response to stdout"""
+
+    def increment(
+        self,
+        method=None,
+        url=None,
+        response=None,
+        error=None,
+        _pool=None,
+        _stacktrace=None,
+    ):  # pragma: no cover
+        log = "\n\n!!A method is being retried!!"
+        if response:
+            if isinstance(response, requests.Response):
+                log += f"\nResponse: {response.url} {response.status_code}"
+            elif isinstance(response, urllib3.HTTPResponse):
+                log += f"\nResponse: {response.url} {response.status}"
+        log += "\n\n"
+        # NOTE: configured to go to stdout as well as logs
+        logger.info(log)
+        sys.stdout.flush()
+        return super().increment(method, url, response, error, _pool, _stacktrace)
+
+
 def create_session_with_retries(
     total_retries: int = 1,
     backoff_factor: int = 1,
     status_forcelist: Optional[List[int]] = None,
     allowed_methods: Optional[List[str]] = None,
     cached_session_name: Optional[str] = None,
+    print_retries: bool = False,
 ) -> requests.Session:
     """Create a session with retries."""
     req_session = (
@@ -535,11 +563,18 @@ def create_session_with_retries(
     # Add retry once after 60s for 500, 502, 503, 504
     # This is to handle the case where the server is starting up
     # or when any AI per-minute token limits are hit
+    status_forcelist = status_forcelist or [429, 500, 502, 503, 504]
+    allowed_methods = allowed_methods or ["POST", "GET", "HEAD"]
+
     kwargs = {
         "total": total_retries,
+        "connect": total_retries,
+        "read": total_retries,
+        "status": total_retries,
         "backoff_factor": backoff_factor,
-        "status_forcelist": status_forcelist or [500, 502, 503, 504],
-        "allowed_methods": allowed_methods or ["POST"],
+        "status_forcelist": status_forcelist,
+        "allowed_methods": set(allowed_methods),
+        "respect_retry_after_header": True,
     }
 
     # Add some more options for urllib3 2.0.0 and above
@@ -547,12 +582,12 @@ def create_session_with_retries(
     if int(urllib3_version[0]) >= 2:  # pragma: no cover
         kwargs.update(
             {
-                "backoff_jitter": 15,
-                "backoff_max": 360,  # Default is 120
+                "backoff_jitter": 0.5,
+                "backoff_max": 120,  # Default is 120
             }
         )
 
-    retries = Retry(**kwargs)
+    retries = StdOutRetry(**kwargs) if print_retries else Retry(**kwargs)
     adapter = HTTPAdapter(max_retries=retries)
     req_session.mount("http://", adapter)
     req_session.mount("https://", adapter)
