@@ -73,6 +73,11 @@ class BaseValidator(ABC):
         List[Union[str, int, MergeKeyCompositeIDParams.IgnoreListIndexType]]
     ] = []
 
+    # For Non-DAPI files, we don't want to generate a file if a file of that entity type exists
+    # (e.g. categories, purposes, etc.)
+    # For DAPI files, we want to generate a file always
+    MUST_GENERATE_EVEN_IF_ENTITY_TYPE_EXISTS: bool = True
+
     SPEC_VERSION: str = NotImplemented
     ENTITY: OpenDAPIEntity = NotImplemented
     INTEGRATION_TYPE: IntegrationType = IntegrationType.STATIC
@@ -371,6 +376,13 @@ class BaseValidator(ABC):
     @functools.cached_property
     def generated_file_state(self) -> Dict[str, Dict]:
         """Collect the raw generated file state"""
+        if (
+            not self.MUST_GENERATE_EVEN_IF_ENTITY_TYPE_EXISTS
+            and self.original_file_state
+        ):
+            # If the entity type exists in the original file state, we don't want to generate a file
+            return {}
+
         base_gen_files = self._get_base_generated_files()
         if self.schema_to_prune_generated:
             for file, content in base_gen_files.items():
