@@ -3,9 +3,11 @@
 # pylint: disable=unused-import
 
 from .activerecord import ActiveRecordDapiValidator
-from .base import BaseDapiValidator, DapiValidator, ORMIntegration
+from .alembic import AlembicDapiValidator
+from .base.main import BaseDapiValidator, DapiValidator, ORMIntegration
 from .dbt import DbtDapiValidator
 from .fallback import FallbackDapiValidator
+from .liquibase import LiquibaseDapiValidator
 from .prisma import PrismaDapiValidator
 from .protobuf import ProtobufDapiValidator
 from .pynamodb import PynamodbDapiValidator
