@@ -2,11 +2,15 @@
 """ActiveRecord DAPI validators."""
 
 import copy
+import functools
 import os
+import re
 from dataclasses import dataclass
 from typing import Dict, List
 from typing import Optional as OptionalType
+from typing import Set
 
+import sentry_sdk
 from pyparsing import Dict as DictParser
 from pyparsing import (
     Group,
@@ -31,7 +35,7 @@ from opendapi.config import (
 )
 from opendapi.models import OverrideConfig, PlaybookConfig
 from opendapi.utils import find_files_with_suffix
-from opendapi.validators.dapi.base import DapiValidator, ORMIntegration
+from opendapi.validators.dapi.base.main import DapiValidator, ORMIntegration
 from opendapi.validators.dapi.models import ProjectInfo
 
 
@@ -167,7 +171,18 @@ class Table:  # pylint: disable=too-many-instance-attributes
 class ActiveRecordProjectInfo(ProjectInfo):
     """Data class for a rails project information"""
 
-    @property
+    @functools.cached_property
+    def missing_tables(self) -> Set[str]:
+        """Get the expected number of tables in the schema."""
+        with open(self.artifact_full_path, "r", encoding="utf-8") as file:
+            total_table_names_in_file = set(
+                re.findall(r'(?i)create_table\s+"([^"]+)"', file.read())
+            )
+            return total_table_names_in_file - {
+                table.table_name for table in self.tables
+            }
+
+    @functools.cached_property
     def tables(self) -> List[Table]:
         """Get the tables in the schema."""
 
@@ -182,6 +197,7 @@ class ActiveRecordProjectInfo(ProjectInfo):
             + ZeroOrMore(quoted_string + Optional(Suppress(",")))
             + Suppress("]")
         )
+        empty_dict = Literal("{}")
         arrows = Literal("->") | Literal("=>")
         ruby_symbol = Suppress(":") + identifier
         comment_line = Suppress("#") + Regex(".*")
@@ -194,6 +210,7 @@ class ActiveRecordProjectInfo(ProjectInfo):
             | string_array
             | ruby_symbol
             | nil
+            | empty_dict
         )
         # t.primary_key "id", :uuid, default: { "gen_random_uuid()" }
         option_val_set = (
@@ -202,17 +219,20 @@ class ActiveRecordProjectInfo(ProjectInfo):
             + Suppress("}")
         )
         # t.primary_key "id", :uuid, default: -> { key1: "gen_random_uuid()" }
+        # partition_by: {strategy: :list, key: ["computed_at"]}
         option_val_dict = DictParser(
             ZeroOrMore(
-                Group(
-                    Suppress("{")
-                    + identifier
-                    + Suppress(":")
-                    + Optional(Suppress(arrows))
-                    + option_val_simple
-                    + Optional(Suppress(","))
-                    + Suppress("}")
+                Suppress("{")
+                + OneOrMore(
+                    Group(
+                        identifier
+                        + Suppress(":")
+                        + Optional(Suppress(arrows))
+                        + option_val_simple
+                        + Optional(Suppress(","))
+                    )
                 )
+                + Suppress("}")
             )
         )
         option_value = option_val_simple | option_val_set | option_val_dict
@@ -228,7 +248,9 @@ class ActiveRecordProjectInfo(ProjectInfo):
             )
         )
 
-        # create_table "table_name", id: :uuid, primary_key: "custom_id", force: true do |t|
+        # create_table "table_name", id: :uuid, primary_key: "custom_id", force: :cascade do |t|
+        # create_table "table_name", id: :uuid, primary_key: "custom_id",
+        # #            partition_by: {strategy: :list, key: ["computed_at"]}, force: :cascade do |t|
         table_start = Group(
             Suppress("create_table")
             + quoted_string("table_name")
@@ -379,7 +401,6 @@ class ActiveRecordProjectInfo(ProjectInfo):
                         ),
                     )
                 )
-
         return tables
 
 
@@ -449,12 +470,18 @@ class ActiveRecordDapiValidator(DapiValidator[ActiveRecordProjectInfo]):
         """Validate the projects"""
         self._assert_schema_files_exist(projects)
 
-    def get_owner_team_urn_for_table(self, table: Table) -> str:
-        """Get the owner team URN for a table."""
-
     def _get_base_generated_files(self) -> Dict[str, Dict]:
         result = {}
         for project in self.selected_projects():
+
+            if project.missing_tables:
+                sentry_sdk.capture_message(
+                    "ActiveRecord parser returned incomplete results "
+                    f"for commit {self.change_trigger_event.after_change_sha} "
+                    f"of repo {self.change_trigger_event.repo_full_name} "
+                    f"and project {project.full_path}: {', '.join(project.missing_tables)}"
+                )
+
             for table in project.tables:
                 if table.is_allowlisted:
                     dapi_location = project.construct_dapi_location(table.table_name)
@@ -464,8 +491,7 @@ class ActiveRecordDapiValidator(DapiValidator[ActiveRecordProjectInfo]):
                         self.add_default_non_generated_schema_portions(
                             {
                                 "urn": dapi_urn,
-                                "owner_team_urn": table.construct_team_urn()
-                                or self.get_owner_team_urn_for_table(table),
+                                "owner_team_urn": table.construct_team_urn(),
                                 "datastores": table.construct_datastores(),
                                 "fields": generated_fields,
                                 "primary_key": table.primary_keys,
