@@ -19,7 +19,7 @@ from opendapi.config import (
 from opendapi.logging import logger
 from opendapi.models import OverrideConfig
 from opendapi.utils import find_files_with_suffix, read_yaml_or_json
-from opendapi.validators.dapi.base import DapiValidator, ORMIntegration
+from opendapi.validators.dapi.base.main import DapiValidator, ORMIntegration
 from opendapi.validators.dapi.mixins.dbt_cloud import DBTCloudMixin, DBTCloudProject
 from opendapi.validators.dapi.models import ProjectInfo
 from opendapi.validators.defs import IntegrationType
@@ -382,22 +382,16 @@ class DbtDapiValidator(DapiValidator[DBTProjectInfo], DBTCloudMixin):
         """Get the branch name"""
         return self.change_trigger_event.branch
 
-    def get_all_dbt_config_files(self) -> List[str]:
-        """Get all the dbt config files"""
-        return find_files_with_suffix(
+    def get_all_projects(self) -> List[DBTProjectInfo]:
+        """List the DBT projects to generate documentation for"""
+        projects = []
+        dbt_config_files = find_files_with_suffix(
             self.root_dir,
             [f"/{self.settings.artifact_path or DBT_CONFIG_YML}"],
             exclude_dirs=["dbt_packages"],
         )
 
-    def get_owner_team_urn_for_table(self, table: DBTModel) -> Optional[str]:
-        """Get the owner team urn for the table"""
-
-    def get_all_projects(self) -> List[DBTProjectInfo]:
-        """List the DBT projects to generate documentation for"""
-        projects = []
-
-        for config_full_path in self.get_all_dbt_config_files():
+        for config_full_path in dbt_config_files:
             # glob for a file called dbt_project.yml within the dbt project
             project_full_path = os.path.normpath(os.path.dirname(config_full_path))
 
@@ -593,8 +587,7 @@ class DbtDapiValidator(DapiValidator[DBTProjectInfo], DBTCloudMixin):
                         {
                             "urn": table.construct_urn(),
                             "description": table.manifest_table_description or None,
-                            "owner_team_urn": table.construct_owner_team_urn()
-                            or self.get_owner_team_urn_for_table(table),
+                            "owner_team_urn": table.construct_owner_team_urn(),
                             "datastores": table.construct_datastores(),
                             "fields": [field.for_dapi() for field in table.columns],
                             "primary_key": table.primary_keys,
