@@ -37,7 +37,7 @@ from opendapi.config import (
 )
 from opendapi.models import OverrideConfig, PlaybookConfig
 from opendapi.utils import find_files_with_suffix
-from opendapi.validators.dapi.base import DapiValidator, ORMIntegration
+from opendapi.validators.dapi.base.main import DapiValidator, ORMIntegration
 from opendapi.validators.dapi.models import ProjectInfo
 
 
@@ -502,9 +502,6 @@ class PrismaDapiValidator(DapiValidator[PrismaProjectInfo]):
         """Verify that all projects and their schema files exist"""
         self._assert_schema_files_exist(projects)
 
-    def get_owner_team_urn_for_table(self, table: Table) -> str:
-        """Get the owner team URN for a table."""
-
     def _get_base_generated_files(self) -> Dict[str, Dict]:
         result = {}
         for project in self.selected_projects():
@@ -515,8 +512,7 @@ class PrismaDapiValidator(DapiValidator[PrismaProjectInfo]):
                         self.add_default_non_generated_schema_portions(
                             {
                                 "urn": table.construct_urn(),
-                                "owner_team_urn": table.construct_team_urn()
-                                or self.get_owner_team_urn_for_table(table),
+                                "owner_team_urn": table.construct_team_urn(),
                                 "datastores": table.construct_datastores(),
                                 "fields": [field.for_dapi() for field in table.columns],
                                 "primary_key": table.primary_keys,
