@@ -25,7 +25,7 @@ from opendapi.config import (
 from opendapi.defs import OPENDAPI_SPEC_URL
 from opendapi.models import OverrideConfig
 from opendapi.utils import find_files_with_suffix
-from opendapi.validators.dapi.base import DapiValidator, ORMIntegration
+from opendapi.validators.dapi.base.main import DapiValidator, ORMIntegration
 from opendapi.validators.dapi.models import ProjectInfo
 from opendapi.validators.defs import IntegrationType
 
