@@ -37,7 +37,8 @@ from opendapi.config import (
     construct_owner_team_urn_from_playbooks,
     is_model_in_allowlist,
 )
-from opendapi.validators.dapi.base import ORMIntegration, PackageScopedDapiValidatorBase
+from opendapi.validators.dapi.base.js import JsProjectsDapiValidatorBase
+from opendapi.validators.dapi.base.main import ORMIntegration
 from opendapi.validators.dapi.models import PackageScopedProjectInfo
 
 # Memoize the parser element to improve performance
@@ -404,7 +405,7 @@ class Table:
     def construct_datastores(self) -> List[str]:
         """Get the datastores for the table."""
         playbooks = self.project.override.playbooks
-        return PackageScopedDapiValidatorBase.add_non_playbook_datastore_fields(
+        return JsProjectsDapiValidatorBase.add_non_playbook_datastore_fields(
             construct_dapi_source_sink_from_playbooks(playbooks, self.name)
             if playbooks
             else {"sources": [], "sinks": []}
@@ -497,7 +498,7 @@ class ProcessedTable(Table):
         return all_columns
 
 
-class TypeOrmDapiValidator(PackageScopedDapiValidatorBase):
+class TypeOrmDapiValidator(JsProjectsDapiValidatorBase):
     """
     Validator class for DAPI files created for TypeORM (TypeScript) models
 
